@@ -255,7 +255,7 @@ println!("{}", String::from_utf8(output.stdout).unwrap());
 # }
 ```
 
-### Parse a Command String
+### Parse a Command String at Runtime
 
 The `command` function can be used to create a `Command` instance with a single command string instead of a program name and scattered arguments. The difference between the `shell` function and the `command` function is that the former is interpreted by the current shell while the latter is parsed by this crate.
 
@@ -273,6 +273,28 @@ command.stdout(Stdio::piped());
 
 let output = command.execute_output().unwrap();
 
+println!("{}", String::from_utf8(output.stdout).unwrap());
+# }
+```
+
+### Parse a Command String at Compile Time
+
+The `command!` macro can be used to create a `Command` instance with a single command string literal instead of a program name and scattered arguments.
+
+```rust
+extern crate execute;
+
+use std::process::{Command, Stdio};
+
+use execute::{Execute, command};
+
+# if cfg!(target_os = "linux") {
+let mut command = execute::command!("cat '/proc/meminfo'");
+
+command.stdout(Stdio::piped());
+
+let output = command.execute_output().unwrap();
+
 println!("{}", String::from_utf8(output.stdout).unwrap());
 # }
 ```
@@ -280,6 +302,10 @@ println!("{}", String::from_utf8(output.stdout).unwrap());
 
 pub extern crate generic_array;
 
+extern crate execute_command_tokens;
+
+extern crate execute_command_macro;
+
 use std::env;
 use std::ffi::{OsStr, OsString};
 use std::io::{self, ErrorKind, Read, Write};
@@ -289,6 +315,10 @@ use std::sync::Once;
 use generic_array::typenum::{IsGreaterOrEqual, True, U1, U256};
 use generic_array::{ArrayLength, GenericArray};
 
+use execute_command_tokens::command_tokens;
+
+pub use execute_command_macro::command;
+
 pub trait Execute {
     /// Execute this command and get the exit status code. stdin will be set to `Stdio::inherit()`. stdout and stderr will be set to `Stdio::null()`.
     fn execute(&mut self) -> Result<Option<i32>, io::Error>;
@@ -739,6 +769,7 @@ impl Execute for Command {
 
 /// Create a `Command` instance which can be executed by the current command language interpreter (shell).
 #[cfg(unix)]
+#[inline]
 pub fn shell<S: AsRef<OsStr>>(cmd: S) -> Command {
     static START: Once = Once::new();
     static mut SHELL: Option<OsString> = None;
@@ -761,6 +792,7 @@ pub fn shell<S: AsRef<OsStr>>(cmd: S) -> Command {
 
 /// Create a `Command` instance which can be executed by the current command language interpreter (shell).
 #[cfg(windows)]
+#[inline]
 pub fn shell<S: AsRef<OsStr>>(cmd: S) -> Command {
     let mut command = Command::new("cmd.exe");
 
@@ -771,78 +803,9 @@ pub fn shell<S: AsRef<OsStr>>(cmd: S) -> Command {
 }
 
 /// Create a `Command` instance by parsing a command string.
+#[inline]
 pub fn command<S: AsRef<str>>(cmd: S) -> Command {
-    let cmd = cmd.as_ref();
-
-    let mut tokens = Vec::with_capacity(1);
-    let mut string_buffer = String::new();
-
-    let mut append_mode = false;
-    let mut quote_mode = false;
-    let mut quote_mode_ending = false; // to deal with '123''456' -> 123456
-    let mut quote_char = ' ';
-    let mut escaping = false;
-
-    for c in cmd.chars() {
-        if escaping {
-            append_mode = true;
-            escaping = false;
-
-            string_buffer.push(c);
-        } else if c.is_whitespace() {
-            if append_mode {
-                if quote_mode {
-                    string_buffer.push(c);
-                } else {
-                    append_mode = false;
-
-                    tokens.push(string_buffer);
-                    string_buffer = String::new();
-                }
-            } else if quote_mode_ending {
-                quote_mode_ending = false;
-
-                tokens.push(string_buffer);
-                string_buffer = String::new();
-            }
-        } else {
-            match c {
-                '"' | '\'' => {
-                    if append_mode {
-                        if quote_mode {
-                            if quote_char == c {
-                                append_mode = false;
-                                quote_mode = false;
-                                quote_mode_ending = true;
-                            } else {
-                                string_buffer.push(c);
-                            }
-                        } else {
-                            quote_mode = true;
-                            quote_char = c;
-                        }
-                    } else {
-                        append_mode = true;
-                        quote_mode = true;
-                        quote_char = c;
-                    }
-                }
-                '\\' => {
-                    escaping = true;
-                }
-                _ => {
-                    append_mode = true;
-                    escaping = false;
-
-                    string_buffer.push(c);
-                }
-            }
-        }
-    }
-
-    if append_mode || quote_mode_ending {
-        tokens.push(string_buffer);
-    }
+    let tokens = command_tokens(cmd);
 
     if tokens.is_empty() {
         Command::new("")
